
// Compiler implementation of the D programming language
// Copyright (c) 1999-2006 by Digital Mars
// All Rights Reserved
// written by Walter Bright
// http://www.digitalmars.com
// License for redistribution is by either the Artistic License
// in artistic.txt, or the GNU General Public License in gnu.txt.
// See the included readme.txt for details.

#ifndef DMD_TOTAL_H
#define DMD_TOTAL_H

#ifdef __DMC__
#pragma once
#endif /* __DMC__ */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>
//#include <wchar.h>

#include "root.h"
#include "stringtable.h"

#include "arraytypes.h"
#include "mars.h"
#include "lexer.h"
#include "parse.h"
#include "identifier.h"
#include "enum.h"
#include "aggregate.h"
#include "mtype.h"
#include "expression.h"
#include "declaration.h"
#include "statement.h"
#include "scope.h"
#include "import.h"
#include "module.h"
#include "id.h"
#include "cond.h"
#include "version.h"
//#include "lib.h"

#endif /* DMD_TOTAL_H */
